@@ -1,6 +1,6 @@
 package Pcore::AE::Handle::ProxyPool::Proxy;
 
-use Pcore qw[-class];
+use Pcore -class;
 use Pcore::AE::Handle::ProxyPool::Proxy::Removed;
 use Pcore::AE::Handle qw[:ALL];
 
@@ -54,8 +54,6 @@ around new => sub ( $orig, $self, $uri, $source ) {
     return $self->$orig($uri_args);
 };
 
-no Pcore;
-
 our $PROXY_TEST_TIMEOUT = 10;
 
 our $CHECK_SCHEME = {
@@ -204,7 +202,7 @@ sub get_slot ( $self, $connect, @ ) {
     my %args = (
         wait   => 0,    # wait for proxy slot
         ban_id => 0,    # check for ban
-        @_[ 2 .. $#_ - 1 ],
+        splice @_, 2, -1,
     );
 
     if ( $self->{connect_error} ) {
@@ -605,13 +603,13 @@ sub _test_scheme_whois ( $self, $scheme, $h, $proxy_type, $cb ) {
 ## ┌──────┬──────────────────────┬────────────────────────────────────────────────────────────────────────────────────────────────────────────────┐
 ## │ Sev. │ Lines                │ Policy                                                                                                         │
 ## ╞══════╪══════════════════════╪════════════════════════════════════════════════════════════════════════════════════════════════════════════════╡
-## │    3 │ 99                   │ References::ProhibitDoubleSigils - Double-sigil dereference                                                    │
+## │    3 │ 97                   │ References::ProhibitDoubleSigils - Double-sigil dereference                                                    │
 ## ├──────┼──────────────────────┼────────────────────────────────────────────────────────────────────────────────────────────────────────────────┤
-## │    3 │ 331                  │ Subroutines::ProtectPrivateSubs - Private subroutine/method used                                               │
+## │    3 │ 329                  │ Subroutines::ProtectPrivateSubs - Private subroutine/method used                                               │
 ## ├──────┼──────────────────────┼────────────────────────────────────────────────────────────────────────────────────────────────────────────────┤
-## │    3 │ 513, 569             │ Subroutines::ProhibitManyArgs - Too many arguments                                                             │
+## │    3 │ 511, 567             │ Subroutines::ProhibitManyArgs - Too many arguments                                                             │
 ## ├──────┼──────────────────────┼────────────────────────────────────────────────────────────────────────────────────────────────────────────────┤
-## │    2 │ 550                  │ ValuesAndExpressions::ProhibitEscapedCharacters - Numeric escapes in interpolated string                       │
+## │    2 │ 548                  │ ValuesAndExpressions::ProhibitEscapedCharacters - Numeric escapes in interpolated string                       │
 ## └──────┴──────────────────────┴────────────────────────────────────────────────────────────────────────────────────────────────────────────────┘
 ##
 ## -----SOURCE FILTER LOG END-----
