@@ -1,6 +1,6 @@
 package Pcore::AE::Handle::ProxyPool::Source::List;
 
-use Pcore qw[-class];
+use Pcore -class;
 
 with qw[Pcore::AE::Handle::ProxyPool::Source];
 
@@ -8,8 +8,6 @@ has proxy => ( is => 'ro', isa => ArrayRef [Str], required => 1 );
 
 has '+load_timeout' => ( default => 0, init_arg => undef );
 
-no Pcore;
-
 sub load ( $self, $cb ) {
     $cb->( $self->proxy );
 
