@@ -2,7 +2,7 @@ package Pcore::Core::CLI::Opt;
 
 # NOTE http://docopt.org/
 
-use Pcore qw[-class];
+use Pcore -class;
 
 with qw[Pcore::Core::CLI::Type];
 
@@ -10,17 +10,19 @@ has name => ( is => 'ro', isa => Str, required => 1 );
 has short => ( is => 'lazy', isa => Maybe [ StrMatch [qr/\A[[:alpha:]]\z/sm] ] );    # undef - disable short option
 has desc => ( is => 'ro', isa => Str );
 
-has type => ( is => 'lazy', isa => Str );
+has type => ( is => 'lazy', isa => Str );                                                                             # option type desc for usage help
 has isa => ( is => 'ro', isa => CodeRef | RegexpRef | ArrayRef | Enum [ keys $Pcore::Core::CLI::Type::TYPE->%* ] );
 
-has default => ( is => 'ro', isa => Str | ArrayRef | HashRef );                      # applied, when option is not exists
-has default_val => ( is => 'ro', isa => Maybe [Str] );                               # applied, when option value is not defined
+has default => ( is => 'ro', isa => Str | ArrayRef | HashRef );                                                       # applied, when option is not exists, possible only for required options
 
-has min => ( is => 'lazy', isa => PositiveOrZeroInt );                               # 0 - option is not required
-has max => ( is => 'lazy', isa => PositiveOrZeroInt );                               # 0 - unlimited repeated
+# NOTE !!!WARNING!!! default_val is not work as it should with Getopt::Long, don't use it now
+has default_val => ( is => 'ro', isa => Maybe [Str] );                                                                # applied, when option value is not defined
 
-has negated => ( is => 'lazy', isa => Bool );
-has hash => ( is => 'ro', isa => Bool, default => 0 );
+has min => ( is => 'lazy', isa => PositiveOrZeroInt );                                                                # 0 - option is not required
+has max => ( is => 'lazy', isa => PositiveOrZeroInt );                                                                # 0 - unlimited repeats
+
+has negated => ( is => 'lazy', isa => Bool );                                                                         # trigger can be used with --no prefix
+has hash => ( is => 'ro', isa => Bool, default => 0 );                                                                # option ia a hash, --opt key=val
 
 has getopt_name   => ( is => 'lazy', isa => Str,  init_arg => undef );
 has is_trigger    => ( is => 'lazy', isa => Bool, init_arg => undef );
@@ -29,11 +31,12 @@ has is_required   => ( is => 'lazy', isa => Bool, init_arg => undef );
 has getopt_spec   => ( is => 'lazy', isa => Str,  init_arg => undef );
 has help_spec     => ( is => 'lazy', isa => Str,  init_arg => undef );
 
-no Pcore;
-
 sub BUILD ( $self, $args ) {
     my $name = $self->name;
 
+    # TODO remove, when this bug will be fixed
+    die qq[Option "$name", don't use default_val until bug with Getopt::Long will be fixed] if defined $self->default_val;
+
     # max
     die qq[Option "$name", "max" must be >= "min" ] if $self->max && $self->max < $self->min;
 
@@ -215,7 +218,7 @@ sub _build_help_spec ($self) {
 sub validate ( $self, $opt ) {
     my $name = $self->name;
 
-    # remap getopt name to name
+    # remap getopt name
     $opt->{$name} = delete $opt->{ $self->getopt_name } if exists $opt->{ $self->getopt_name };
 
     if ( !exists $opt->{$name} ) {
@@ -247,6 +250,9 @@ sub validate ( $self, $opt ) {
 
         if ( $self->is_trigger ) {
             $count = $opt->{$name};
+
+            # do not check min / max for the repeatable trigger with default = 0
+            goto VALIDATE if $count == 0;
         }
         elsif ( !ref $opt->{$name} ) {
             $count = 1;
@@ -265,6 +271,8 @@ sub validate ( $self, $opt ) {
         return qq[option "$name" can be repeated not more, than @{[$self->max]} time(s)] if $self->max && $count > $self->max;
     }
 
+  VALIDATE:
+
     # validate option value type
     if ( defined $self->isa && ( my $error_msg = $self->_validate_isa( $opt->{$name} ) ) ) {
         return qq[option "$name" $error_msg];
@@ -280,9 +288,9 @@ sub validate ( $self, $opt ) {
 ## ┌──────┬──────────────────────┬────────────────────────────────────────────────────────────────────────────────────────────────────────────────┐
 ## │ Sev. │ Lines                │ Policy                                                                                                         │
 ## ╞══════╪══════════════════════╪════════════════════════════════════════════════════════════════════════════════════════════════════════════════╡
-## │    3 │ 14, 258              │ References::ProhibitDoubleSigils - Double-sigil dereference                                                    │
+## │    3 │ 14, 264              │ References::ProhibitDoubleSigils - Double-sigil dereference                                                    │
 ## ├──────┼──────────────────────┼────────────────────────────────────────────────────────────────────────────────────────────────────────────────┤
-## │    3 │ 34                   │ Subroutines::ProhibitExcessComplexity - Subroutine "BUILD" with high complexity score (34)                     │
+## │    3 │ 34                   │ Subroutines::ProhibitExcessComplexity - Subroutine "BUILD" with high complexity score (35)                     │
 ## └──────┴──────────────────────┴────────────────────────────────────────────────────────────────────────────────────────────────────────────────┘
 ##
 ## -----SOURCE FILTER LOG END-----
