@@ -1,30 +1,26 @@
 package Pcore::Core::H::Cache;
 
-use Pcore qw[-class -autoload];
+use Pcore -class, -autoload;
+use Pcore::Util::Scalar qw[blessed isweak weaken];
 
 has _h_cache => ( is => 'lazy', isa => HashRef [ ConsumerOf ['Pcore::Core::H::Role'] ], init_arg => undef );
 has _h_supported_events => ( is => 'lazy', isa => HashRef, init_arg => undef );
 
-sub _build__h_cache {
-    my $self = shift;
-
+sub _build__h_cache ($self) {
     P->EV->register( 'CORE#PROC::BEFORE_FORK' => \&_h_ev_before_fork, args => [ \$self ] );
 
     return {};
 }
 
-sub _build__h_supported_events {
-    my $self = shift;
-
+sub _build__h_supported_events ($self) {
     return {
         PID_CHANGE  => 1,
         BEFORE_FORK => 1,
     };
 }
 
-sub _h_ev_before_fork {
-    my $ev   = shift;
-    my $self = ${ shift @_ };
+sub _h_ev_before_fork ( $ev, $self ) {
+    $self = $self->$*;
 
     if ($self) {
         $self->run_event('BEFORE_FORK');
@@ -36,10 +32,7 @@ sub _h_ev_before_fork {
     return;
 }
 
-sub run_event {
-    my $self  = shift;
-    my $event = shift;
-
+sub run_event ( $self, $event ) {
     for my $id ( grep { $self->_h_cache->{$_}->{event} && $self->_h_cache->{$_}->{event} eq $event } keys %{ $self->_h_cache } ) {
         if ( my $h = $self->_get($id) ) {
             $h->h_disconnect;
@@ -49,10 +42,7 @@ sub run_event {
     return;
 }
 
-sub _get {
-    my $self = shift;
-    my $id   = shift;
-
+sub _get ( $self, $id ) {
     my $cache_id = $self->_h_cache->{$id};
 
     if ( !$cache_id->{h} ) {
@@ -62,12 +52,10 @@ sub _get {
     }
     else {
         if ( $cache_id->{event} && $cache_id->{event} eq 'PID_CHANGE' ) {
-            my $pid = P->sys->pid;
-
-            if ( $cache_id->{pid} && $cache_id->{pid} ne $pid ) {
+            if ( $cache_id->{pid} && $cache_id->{pid} ne $$ ) {
                 $cache_id->{h}->h_disconnect;
 
-                $cache_id->{pid} = $pid;
+                $cache_id->{pid} = $$;
             }
         }
 
@@ -75,36 +63,30 @@ sub _get {
     }
 }
 
-sub autoload {
-    my $self = shift;
-    my $id   = shift;
+sub _AUTOLOAD ( $self, $method, @ ) {
+    die qq[Handle "$method" not exists in cache] unless $self->_h_cache->{$method};
 
-    die qq[Handle "$id" not exists in cache] unless $self->_h_cache->{$id};
-
-    return sub {
-        my $self = shift;
-
-        if ( my $h = $self->_get($id) ) {
-            return $h;
-        }
-        else {
-            die qq[Handle "$id" was removed from cache];
-        }
-    }, not_create_method => 0;
+    return <<"PERL";
+        sub (\$self) {
+            if ( my \$h = \$self->_get(q[$method]) ) {
+                return \$h;
+            }
+            else {
+                die qq[Handle "$method" was removed from cache];
+            }
+        };
+PERL
 }
 
 # PUBLIC
-sub add {
-    my $self  = shift;
-    my $id    = shift;
-    my $class = shift;
-    my %args  = (@_);
+sub add ( $self, $id, $class, %args ) {
 
     # handle object ref can be weak if not exists in cache (new handle) or already weaken
-    my $can_weak = $self->_h_cache->{$id}->{h} ? P->scalar->isweak( $self->_h_cache->{$id}->{h} ) : 1;
+    my $can_weak = $self->_h_cache->{$id}->{h} ? isweak( $self->_h_cache->{$id}->{h} ) : 1;
 
     my $h;
-    if ( P->scalar->blessed($class) ) {
+
+    if ( blessed($class) ) {
         $h     = $class;
         $class = ref $class;
     }
@@ -117,11 +99,11 @@ sub add {
     $self->_h_cache->{$id} = {
         h     => $h,
         event => $h->h_disconnect_on,
-        pid   => P->sys->pid,
+        pid   => $$,
     };
 
     if ( defined wantarray ) {
-        P->scalar->weaken( $self->_h_cache->{$id}->{h} ) if $can_weak;
+        weaken( $self->_h_cache->{$id}->{h} ) if $can_weak;
 
         return $h;
     }
@@ -130,16 +112,23 @@ sub add {
     }
 }
 
-sub remove {
-    my $self = shift;
-    my $id   = shift;
-
+sub remove ( $self, $id ) {
     delete $self->_h_cache->{$id};
 
     return;
 }
 
 1;
+## -----SOURCE FILTER LOG BEGIN-----
+##
+## PerlCritic profile "pcore-script" policy violations:
+## ┌──────┬──────────────────────┬────────────────────────────────────────────────────────────────────────────────────────────────────────────────┐
+## │ Sev. │ Lines                │ Policy                                                                                                         │
+## ╞══════╪══════════════════════╪════════════════════════════════════════════════════════════════════════════════════════════════════════════════╡
+## │    3 │ 66                   │ Subroutines::ProhibitUnusedPrivateSubroutines - Private subroutine/method '_AUTOLOAD' declared but not used    │
+## └──────┴──────────────────────┴────────────────────────────────────────────────────────────────────────────────────────────────────────────────┘
+##
+## -----SOURCE FILTER LOG END-----
 __END__
 =pod
 
