@@ -1,8 +1,6 @@
 package <: $module_name :> v0.1.0;
 
-use Pcore qw[-class];
-
-
+use Pcore -class;
 
 1;
 __END__
